import{s as _t,n as xt,o as Ct}from"../chunks/scheduler.7bc62968.js";import{S as Lt,i as Ht,g as s,s as n,r as k,A as Tt,h as o,f as a,c as l,j as bt,u as P,x as r,k as $t,y as Mt,a as i,v as S,d as A,t as q,w as I}from"../chunks/index.66556066.js";import{H as D}from"../chunks/Heading.3f0870db.js";function kt(st){let d,U,R,E,h,j,c,ot="Have you ever tried to get hold of some data for your problem, be it a machine learning problem or some other development-related problem, and you just couldn’t find enough data? Either the data is closed-source and unavailable to you, or it is prohibitively costly or time-consuming to acquire. How do we deal with such a situation?",W,m,rt='Well, one solution is synthetic data. Synthetic data is generated by a model to be used in place of real data or with real data. Here, by model, we don’t mean only machine learning or deep learning models; they can be simple mathematical or statistical models too, like a set of (stochastic) differential equations modeling a physical or economic <a href="https://link.springer.com/book/10.1007/978-3-319-56436-4" rel="nofollow">system</a>. Feeling excited yet? Let’s dive more into the details of synthetic data: what it is, how it is generated, and its benefits. You might be able to answer the last one a little by now ;)',O,p,V,u,dt='As <a href="https://arxiv.org/abs/2205.03257" rel="nofollow">Royal Society</a> defines, synthetic data is the data generated using a purpose-built mathematical model or algorithm to solve a (set of) data science task(s). Keep in mind that synthetic data only mimics the real data and is not generated by real events. Ideally, the synthetic data should have the same statistical properties as the real data it is supplementing. It has many uses, such as improving AI models, protecting sensitive data, and mitigating bias.',B,f,G,y,ht="Before answering this question, let’s talk a little bit about why real data is not sufficient anymore. Some of the non-exhaustive problems with real data are:",N,g,ct="<li>It can be messy and very hard to deal with.</li> <li>Inter-company data sharing might not be possible due to privacy issues.</li> <li>Medical data is confidential and hence cannot be shared openly.</li> <li>It can be biased.</li> <li>Data collection and annotation can be expensive.</li>",F,v,mt="Most of the above-mentioned problems can potentially be solved by synthetic data:",K,w,pt="<li>Synthetic data are generated in a structured form, and hence, they are easy to deal with.</li> <li>Companies can train synthetic data generation models that learn the distribution of the original data but don’t reveal anything about individual data points in the original data and hence maintain privacy. A similar approach can be taken for medical data.</li> <li>We can train the data generator model to generate de-biased data.</li> <li>Synthetic data can be augmented with real data to make the models or applications more robust.</li>",Y,b,J,$,ut="Here, we mention some of the ways to generate synthetic data:",Q,_,ft='<li>CAD &amp; Blender: Allows the creation of photorealistic image datasets of 3D scenes while controlling parameters. It enables computing metrics by comparing the synthesized data to the ground truth (generation parameters). It is a very robust method but limited in generation quality, diversity, and quantity. Use cases include using <a href="https://amazon-berkeley-objects.s3.amazonaws.com/static_html/ABO_CVPR2022.pdf" rel="nofollow">commercial applications</a>, generating <a href="https://arxiv.org/abs/2109.15102" rel="nofollow">synthetic faces</a>, and <a href="https://openaccess.thecvf.com/content_CVPR_2020/papers/Mu_Learning_From_Synthetic_Animals_CVPR_2020_paper.pdf" rel="nofollow">monitoring wildlife</a>.</li> <li>Deep generative models (Transformers/GANs/Diffusion models): Allow expanding a dataset, tackling data imbalance, and solving privacy issues. Very convenient and powerful but can create datasets with biases, incoherence, and repetitiveness, which induces an important overtraining risk and produces a restricted set of predictions. Use cases include <a href="https://rdcu.be/dokei" rel="nofollow">medical image generation</a>, <a href="https://www.mdpi.com/2073-4395/12/10/2395" rel="nofollow">efficient plant disease identification</a>, <a href="https://arxiv.org/abs/2303.14828" rel="nofollow">industrial waste sorting</a>, <a href="https://arxiv.org/abs/2101.04927" rel="nofollow">traffic sign recognition</a>, and <a href="https://computer-vision-in-the-wild.github.io/eccv-2022/static/eccv2022/camera_ready/ECCV_2022_cvinw_Domain_Compatible_Synthetic_Data_Generation.pdf" rel="nofollow">detection of emergency vehicles for an autonomous driving car application</a>.</li>',X,x,yt="In this unit, we will introduce the following methods to generate synthetic data: physically-based rendering, point clouds,  and GANs.",Z,C,tt,L,gt="Now that we have seen the power and uses of synthetic data, let’s take some time out to discuss its challenges:",et,H,vt="<li>Synthetic data is not inherently private: Synthetic data can also leak information about the data it was derived from and is vulnerable to privacy attacks. Significant care is required to generate private synthetic data.</li> <li>Outliers can be hard to capture privately: Outliers and low probability events, as are often found in real data, are particularly difficult to capture and to be privately included in a synthetic dataset.</li> <li>Empirically evaluating the privacy of a single dataset can be problematic: Rigorous notions of privacy (e.g., differential privacy) are a requirement on the mechanism that generated a synthetic dataset rather than on the dataset itself.</li> <li>Black box models can be particularly opaque when it comes to generating synthetic data: Overparameterised generative models excel in producing high-dimensional synthetic data, but the levels of accuracy and privacy of these datasets are hard to estimate and can vary significantly across produced data points.</li>",at,T,it,M,wt='<li><a href="https://arxiv.org/abs/2302.04062" rel="nofollow">Machine Learning for Synthetic Data Generation: A Review</a></li> <li><a href="https://arxiv.org/abs/2205.03257" rel="nofollow">Synthetic Data — what, why and how?</a></li> <li>One very interesting application of synthetic data: <a href="https://www.thispersondoesnotexist.com/" rel="nofollow">this person does not exist</a></li>',nt,z,lt;return h=new D({props:{title:"Introduction",local:"introduction",headingTag:"h1"}}),p=new D({props:{title:"What is synthetic data?",local:"what-is-synthetic-data",headingTag:"h2"}}),f=new D({props:{title:"Why would you use synthetic data?",local:"why-would-you-use-synthetic-data",headingTag:"h2"}}),b=new D({props:{title:"How to generate synthetic data?",local:"how-to-generate-synthetic-data",headingTag:"h2"}}),C=new D({props:{title:"Challenges with synthetic data",local:"challenges-with-synthetic-data",headingTag:"h2"}}),T=new D({props:{title:"Resources",local:"resources",headingTag:"h2"}}),{c(){d=s("meta"),U=n(),R=s("p"),E=n(),k(h.$$.fragment),j=n(),c=s("p"),c.textContent=ot,W=n(),m=s("p"),m.innerHTML=rt,O=n(),k(p.$$.fragment),V=n(),u=s("p"),u.innerHTML=dt,B=n(),k(f.$$.fragment),G=n(),y=s("p"),y.textContent=ht,N=n(),g=s("ul"),g.innerHTML=ct,F=n(),v=s("p"),v.textContent=mt,K=n(),w=s("ul"),w.innerHTML=pt,Y=n(),k(b.$$.fragment),J=n(),$=s("p"),$.textContent=ut,Q=n(),_=s("ul"),_.innerHTML=ft,X=n(),x=s("p"),x.textContent=yt,Z=n(),k(C.$$.fragment),tt=n(),L=s("p"),L.textContent=gt,et=n(),H=s("ul"),H.innerHTML=vt,at=n(),k(T.$$.fragment),it=n(),M=s("ul"),M.innerHTML=wt,nt=n(),z=s("p"),this.h()},l(t){const e=Tt("svelte-u9bgzb",document.head);d=o(e,"META",{name:!0,content:!0}),e.forEach(a),U=l(t),R=o(t,"P",{}),bt(R).forEach(a),E=l(t),P(h.$$.fragment,t),j=l(t),c=o(t,"P",{"data-svelte-h":!0}),r(c)!=="svelte-o1332z"&&(c.textContent=ot),W=l(t),m=o(t,"P",{"data-svelte-h":!0}),r(m)!=="svelte-nw5bt9"&&(m.innerHTML=rt),O=l(t),P(p.$$.fragment,t),V=l(t),u=o(t,"P",{"data-svelte-h":!0}),r(u)!=="svelte-18jz4hw"&&(u.innerHTML=dt),B=l(t),P(f.$$.fragment,t),G=l(t),y=o(t,"P",{"data-svelte-h":!0}),r(y)!=="svelte-1k2ejb3"&&(y.textContent=ht),N=l(t),g=o(t,"UL",{"data-svelte-h":!0}),r(g)!=="svelte-eey89z"&&(g.innerHTML=ct),F=l(t),v=o(t,"P",{"data-svelte-h":!0}),r(v)!=="svelte-18sbrq7"&&(v.textContent=mt),K=l(t),w=o(t,"UL",{"data-svelte-h":!0}),r(w)!=="svelte-10bnq1j"&&(w.innerHTML=pt),Y=l(t),P(b.$$.fragment,t),J=l(t),$=o(t,"P",{"data-svelte-h":!0}),r($)!=="svelte-p5z7gv"&&($.textContent=ut),Q=l(t),_=o(t,"UL",{"data-svelte-h":!0}),r(_)!=="svelte-rfai8v"&&(_.innerHTML=ft),X=l(t),x=o(t,"P",{"data-svelte-h":!0}),r(x)!=="svelte-wy9mdv"&&(x.textContent=yt),Z=l(t),P(C.$$.fragment,t),tt=l(t),L=o(t,"P",{"data-svelte-h":!0}),r(L)!=="svelte-3g69fp"&&(L.textContent=gt),et=l(t),H=o(t,"UL",{"data-svelte-h":!0}),r(H)!=="svelte-qdi0lm"&&(H.innerHTML=vt),at=l(t),P(T.$$.fragment,t),it=l(t),M=o(t,"UL",{"data-svelte-h":!0}),r(M)!=="svelte-1cesuwc"&&(M.innerHTML=wt),nt=l(t),z=o(t,"P",{}),bt(z).forEach(a),this.h()},h(){$t(d,"name","hf:doc:metadata"),$t(d,"content",Pt)},m(t,e){Mt(document.head,d),i(t,U,e),i(t,R,e),i(t,E,e),S(h,t,e),i(t,j,e),i(t,c,e),i(t,W,e),i(t,m,e),i(t,O,e),S(p,t,e),i(t,V,e),i(t,u,e),i(t,B,e),S(f,t,e),i(t,G,e),i(t,y,e),i(t,N,e),i(t,g,e),i(t,F,e),i(t,v,e),i(t,K,e),i(t,w,e),i(t,Y,e),S(b,t,e),i(t,J,e),i(t,$,e),i(t,Q,e),i(t,_,e),i(t,X,e),i(t,x,e),i(t,Z,e),S(C,t,e),i(t,tt,e),i(t,L,e),i(t,et,e),i(t,H,e),i(t,at,e),S(T,t,e),i(t,it,e),i(t,M,e),i(t,nt,e),i(t,z,e),lt=!0},p:xt,i(t){lt||(A(h.$$.fragment,t),A(p.$$.fragment,t),A(f.$$.fragment,t),A(b.$$.fragment,t),A(C.$$.fragment,t),A(T.$$.fragment,t),lt=!0)},o(t){q(h.$$.fragment,t),q(p.$$.fragment,t),q(f.$$.fragment,t),q(b.$$.fragment,t),q(C.$$.fragment,t),q(T.$$.fragment,t),lt=!1},d(t){t&&(a(U),a(R),a(E),a(j),a(c),a(W),a(m),a(O),a(V),a(u),a(B),a(G),a(y),a(N),a(g),a(F),a(v),a(K),a(w),a(Y),a(J),a($),a(Q),a(_),a(X),a(x),a(Z),a(tt),a(L),a(et),a(H),a(at),a(it),a(M),a(nt),a(z)),a(d),I(h,t),I(p,t),I(f,t),I(b,t),I(C,t),I(T,t)}}}const Pt='{"title":"Introduction","local":"introduction","sections":[{"title":"What is synthetic data?","local":"what-is-synthetic-data","sections":[],"depth":2},{"title":"Why would you use synthetic data?","local":"why-would-you-use-synthetic-data","sections":[],"depth":2},{"title":"How to generate synthetic data?","local":"how-to-generate-synthetic-data","sections":[],"depth":2},{"title":"Challenges with synthetic data","local":"challenges-with-synthetic-data","sections":[],"depth":2},{"title":"Resources","local":"resources","sections":[],"depth":2}],"depth":1}';function St(st){return Ct(()=>{new URLSearchParams(window.location.search).get("fw")}),[]}class Dt extends Lt{constructor(d){super(),Ht(this,d,St,kt,_t,{})}}export{Dt as component};
